@@ -208,6 +208,7 @@ class CP(object):
 
     def state(self, postal_code):
         """
+        
         >>> from text_models.place import CP
         >>> cp = CP()
         >>> cp.state("20900")
@@ -235,6 +236,7 @@ class Travel(object):
         self._cp = CP()
         self._dates = list()
         delta = datetime.timedelta(days=1)
+        init = datetime.datetime(year=2015, month=12, day=16)
         if day is None:
             _ = time.localtime()
             day = datetime.datetime(year=_.tm_year,
@@ -242,7 +244,7 @@ class Travel(object):
                                     day=_.tm_mday) - delta
                                            
         days = []
-        while len(days) < window:
+        while len(days) < window and day >= init:
             try:
                 fname = download_geo("%s%02i%02i.travel" % (str(day.year)[-2:],
                                                             day.month,
@@ -278,6 +280,23 @@ class Travel(object):
             return None
         return self._cp.postal_code_names[key][0]
 
+
+    def country(self, key):
+        """
+        Country that correspond to the key.
+        
+        >>> from text_models.place import Travel
+        >>> travel = Travel(window=1)
+        >>> travel.country("20900")
+        'MX'
+        >>> travel.country("US")
+        'US'
+        
+        """
+
+        if len(key) == 5:
+            return "MX"
+        return key
     
     def displacement(self, level=None):
         """
